==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/types/Callbacks.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test.types {

   public class Callbacks: RTest {
      
      public Callbacks() : base() {
      }
      public String name;
      
      public void objectOnActivate(ObjectContainer container) {
         Console.WriteLine("onActivate");
      }
      
      public void objectOnDeactivate(ObjectContainer container) {
         Console.WriteLine("onDeactivate");
      }
      
      public void objectOnDelete(ObjectContainer container) {
         Console.WriteLine("onDelete");
      }
      
      public void objectOnNew(ObjectContainer container) {
         Console.WriteLine("onNew");
      }
      
      public void objectOnUpdate(ObjectContainer container) {
         Console.WriteLine("onUpdate");
      }
      
      public override void set(int ver) {
         if (ver == 1) {
            name = "OneONEOneONEOneONEOneONEOneONEOneONE";
         } else {
            name = "TwoTWOTwoTWOTwoTWOTwoTWOTwoTWO";
         }
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/types/Callbacks.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test.types {

   public class Callbacks: RTest {
      
      public Callbacks() : base() {
      }
      public String name;
      
      public void ObjectOnActivate(ObjectContainer container) {
         Console.WriteLine("onActivate");
      }
      
      public void ObjectOnDeactivate(ObjectContainer container) {
         Console.WriteLine("onDeactivate");
      }
      
      public void ObjectOnDelete(ObjectContainer container) {
         Console.WriteLine("onDelete");
      }
      
      public void ObjectOnNew(ObjectContainer container) {
         Console.WriteLine("onNew");
      }
      
      public void ObjectOnUpdate(ObjectContainer container) {
         Console.WriteLine("onUpdate");
      }
      
      public override void Set(int ver) {
         if (ver == 1) {
            name = "OneONEOneONEOneONEOneONEOneONEOneONE";
         } else {
            name = "TwoTWOTwoTWOTwoTWOTwoTWOTwoTWO";
         }
      }
   }
}
